/***************************************************************************
*   Copyright (C) 2004 by Kita Developers                                 *
*   ikemo@users.sourceforge.jp                                            *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

/* obsolete */

#ifndef KITAPARMISC_H
#define KITAPARMISC_H

#include "kita_misc.h"

class KURL;

namespace Kita
{

    class ParseMisc
    {
    public:
        static KURL parseURL( const KURL& url , QString& refstr )
        {
            return Kita::getDatURL( url , refstr );
        }

        static KURL parseURLonly( const KURL& url ) { return Kita::getDatURL( url ); }

        static QString utf8ToUnicode( const QString& str ) { return Kita::utf8ToUnicode( str ); }
    };

}

#endif

